==> order-center-domain-3.1.0-CLOUD-TEST-20230825.111032-87-sources.jar: com/tydic/dyc/oc/model/common/IUocCommonModel.java <==
package com.tydic.dyc.oc.model.common;

import com.tydic.dyc.oc.model.cmporder.qrybo.UocQryCmpOrderNoBo;
import com.tydic.dyc.oc.model.common.qrybo.*;
import com.tydic.dyc.oc.model.common.sub.UocCfcParamConfigDo;
import com.tydic.dyc.oc.model.common.sub.UocCfcParamConfigItemDo;
import com.tydic.dyc.oc.model.common.sub.UocConfSupplierDO;
import com.tydic.dyc.oc.model.common.sub.UocOutLogSaveDo;
import com.tydic.dyc.oc.model.order.sub.UocOrderQueryIndex;
import com.tydic.dyc.oc.model.order.sub.UocOrderTaskInst;
import com.tydic.dyc.oc.model.order.sub.UocTodo;

import java.util.List;

/**
 * 标题:IUocCommonModel
 * 说明:公共model
 * 时间:2022/4/1 10:21
 * 作者:罗有
 */

public interface IUocCommonModel {
    /*
     * @Author lsl
     * @Description //TODO 根据供应商编码查询对应的供应商配置信息
     * @Date 18:02 2022/4/7
     * @Param [goodsSupplierNo]
     * @return
     */
    UocConfSupplierBo qryConfSupplier(String goodsSupplierNo);

    List<UocConfSupplierDO> qryConfSupplierList(UocConfSupplierDO uocConfSupplierDO);

    /**
     * 上传服务
     * @param uocCommonDo
     * @return
     */
    UocCommonDo uploadFile(UocCommonDo uocCommonDo);

    /**
     * 描述:保存外部关联数据
     * @param index 入参
     * @return int
     * @author tgy
     * @date 2022/4/13 10:35
     */
    int saveOrderQueryIndex(UocOrderQueryIndex index);

    UocCommonDo dealTask(UocCommonDo uocCommonDo);

    List<UocOrderTaskInst> qryTaskInst(UocOrderTaskInst uocOrderTaskInst);

    /**
     * 保存待办信息
     * @param uocTodo
     * @return
     */
    int saveTodoInfo(UocTodo uocTodo);

    /**
     * 根据主键id更新待办信息
     * @param uocTodo
     * @return
     */
    int updateTodoById(UocTodo uocTodo);

    /**
     * 查询单条待办信息
     * @param uocTodo
     * @return
     */
    UocTodo getTodoInfo(UocTodo uocTodo);

    /**
     * 查询多条待办信息
     * @param uocTodo
     * @return
     */
    List<UocTodo> getTodoListInfo(UocTodo uocTodo);

    /**
     * 批量插入待办信息
     * @param list
     */
    void insertBatchTodo(List<UocTodo> list);

    /**
     * 描述:根据配置编码查询配置及配置明细信息
     * @param paramCode 参数编码
     * @return com.tydic.dyc.oc.model.common.sub.UocCfcParamConfigDo
     * @author tgy
     * @date 2023/1/4 11:03
     */
    UocCfcParamConfigDo qryCfcParamByCode(String paramCode);

    /**
     * 描述:更新配置项
     * @param reqDo 入参
     * @return com.tydic.dyc.oc.model.common.sub.UocCfcParamConfigDo
     * @author tgy
     * @date 2023/1/4 11:02
     */
    UocCfcParamConfigItemDo updateCfcItemValue(UocCfcParamConfigItemDo reqDo);

    /**
     * 描述:根据skuid查询物料编码
     * @param qryBo 入参
     * @return com.tydic.dyc.oc.model.common.qrybo.UocQryMateriaOrderNoBo
     * @author tgy
     * @date 2023/1/6 19:06
     */
    UocQryMateriaOrderNoBo qryMateriaBySkuIdAndUserId(UocQryMateriaOrderNoBo qryBo) ;

    /**
     * 描述根据订单状态查询订单阶段
     * @param qryBo 入参
     * @return com.tydic.dyc.oc.model.common.qrybo.UocQrySaleOrderStageBO
     * @author 印昌盛
     * @date 2023/1/13 10:50
     */
    UocQrySaleOrderStageBO qrySaleOrderStageByOrderStateAndprocState(UocQrySaleOrderStageBO qryBo);

    /**
     * 描述: 查询配置调用服务
     * @param callServerClassName 入参
     * @return java.lang.String
     * @author tgy
     * @date 2023/7/24 14:16
     */
    UocQryStateCalculatorBo qryUocStateCalculatorServerConfig(String callServerClassName);

    /**
     * 描述: 查询订单状态变更日志最后一个新状态
     * @param qryBo 入参
     * @return java.lang.String
     * @author tgy
     * @date 2023/7/24 15:30
     */
    UocQryOrderStateChngLogBo qryUocLastChngStateByObjId(UocQryOrderStateChngLogBo qryBo);

    UocOutLogSaveDo saveOutLog(UocOutLogSaveDo reqDo);

}

==> order-center-domain-3.2.2-CLOUD-TEST-20240528.094951-21-sources.jar: com/tydic/dyc/oc/model/common/IUocCommonModel.java <==
package com.tydic.dyc.oc.model.common;

import com.tydic.dyc.oc.model.cmporder.qrybo.UocQryCmpOrderNoBo;
import com.tydic.dyc.oc.model.common.qrybo.*;
import com.tydic.dyc.oc.model.common.sub.UocCfcParamConfigDo;
import com.tydic.dyc.oc.model.common.sub.UocCfcParamConfigItemDo;
import com.tydic.dyc.oc.model.common.sub.UocConfSupplierDO;
import com.tydic.dyc.oc.model.common.sub.UocOutLogSaveDo;
import com.tydic.dyc.oc.model.order.sub.UocOrderQueryIndex;
import com.tydic.dyc.oc.model.order.sub.UocOrderTaskInst;
import com.tydic.dyc.oc.model.order.sub.UocTodo;
import com.tydic.dyc.oc.service.domainservice.bo.UocQryInspItemsServiceReqBo;
import com.tydic.dyc.oc.service.domainservice.bo.UocQryInspItemsServiceRspBo;

import java.util.List;

/**
 * 标题:IUocCommonModel
 * 说明:公共model
 * 时间:2022/4/1 10:21
 * 作者:罗有
 */

public interface IUocCommonModel {
    /*
     * @Author lsl
     * @Description //TODO 根据供应商编码查询对应的供应商配置信息
     * @Date 18:02 2022/4/7
     * @Param [goodsSupplierNo]
     * @return
     */
    UocConfSupplierBo qryConfSupplier(String goodsSupplierNo);

    List<UocConfSupplierDO> qryConfSupplierList(UocConfSupplierDO uocConfSupplierDO);

    /**
     * 上传服务
     * @param uocCommonDo
     * @return
     */
    UocCommonDo uploadFile(UocCommonDo uocCommonDo);

    /**
     * 描述:保存外部关联数据
     * @param index 入参
     * @return int
     * @author tgy
     * @date 2022/4/13 10:35
     */
    int saveOrderQueryIndex(UocOrderQueryIndex index);

    UocCommonDo dealTask(UocCommonDo uocCommonDo);

    List<UocOrderTaskInst> qryTaskInst(UocOrderTaskInst uocOrderTaskInst);

    /**
     * 保存待办信息
     * @param uocTodo
     * @return
     */
    int saveTodoInfo(UocTodo uocTodo);

    /**
     * 根据主键id更新待办信息
     * @param uocTodo
     * @return
     */
    int updateTodoById(UocTodo uocTodo);

    /**
     * 查询单条待办信息
     * @param uocTodo
     * @return
     */
    UocTodo getTodoInfo(UocTodo uocTodo);

    /**
     * 查询多条待办信息
     * @param uocTodo
     * @return
     */
    List<UocTodo> getTodoListInfo(UocTodo uocTodo);

    /**
     * 批量插入待办信息
     * @param list
     */
    void insertBatchTodo(List<UocTodo> list);

    /**
     * 描述:根据配置编码查询配置及配置明细信息
     * @param paramCode 参数编码
     * @return com.tydic.dyc.oc.model.common.sub.UocCfcParamConfigDo
     * @author tgy
     * @date 2023/1/4 11:03
     */
    UocCfcParamConfigDo qryCfcParamByCode(String paramCode);

    /**
     * 描述:更新配置项
     * @param reqDo 入参
     * @return com.tydic.dyc.oc.model.common.sub.UocCfcParamConfigDo
     * @author tgy
     * @date 2023/1/4 11:02
     */
    UocCfcParamConfigItemDo updateCfcItemValue(UocCfcParamConfigItemDo reqDo);

    /**
     * 描述:根据skuid查询物料编码
     * @param qryBo 入参
     * @return com.tydic.dyc.oc.model.common.qrybo.UocQryMateriaOrderNoBo
     * @author tgy
     * @date 2023/1/6 19:06
     */
    UocQryMateriaOrderNoBo qryMateriaBySkuIdAndUserId(UocQryMateriaOrderNoBo qryBo) ;

    /**
     * 描述根据订单状态查询订单阶段
     * @param qryBo 入参
     * @return com.tydic.dyc.oc.model.common.qrybo.UocQrySaleOrderStageBO
     * @author 印昌盛
     * @date 2023/1/13 10:50
     */
    UocQrySaleOrderStageBO qrySaleOrderStageByOrderStateAndprocState(UocQrySaleOrderStageBO qryBo);

    /**
     * 描述: 查询配置调用服务
     * @param callServerClassName 入参
     * @return java.lang.String
     * @author tgy
     * @date 2023/7/24 14:16
     */
    UocQryStateCalculatorBo qryUocStateCalculatorServerConfig(String callServerClassName);

    /**
     * 描述: 查询订单状态变更日志最后一个新状态
     * @param qryBo 入参
     * @return java.lang.String
     * @author tgy
     * @date 2023/7/24 15:30
     */
    UocQryOrderStateChngLogBo qryUocLastChngStateByObjId(UocQryOrderStateChngLogBo qryBo);

    UocOutLogSaveDo saveOutLog(UocOutLogSaveDo reqDo);

    UocQryInspItemsServiceRspBo qryInspItems(UocQryInspItemsServiceReqBo reqBo);

}
